@@ -36,14 +36,14 @@
 #'a factor of length \eqn{p} that is in the same order as the
 #'columns of \code{expr} (when it is a dataframe) and that contains the patient
 #'identifier of each sample.
-#'@TODO See Details.
+#TODO See Details.
 #'
 #'@param TimePoint 
 #'a numeric vector or a factor of length \eqn{p} that is in
-#'the same order as \code{TimePoint} and the columns of \code{expr} (when it is
+#'the same order as \code{Subject_ID} and the columns of \code{expr} (when it is
 #'a dataframe), and that contains the time points at which gene expression was
 #'measured.
-#'@TODO See Details.
+#TODO See Details.
 #'
 #'@param geneset.name 
 #'a character string containing the name of the gene set to
@@ -55,7 +55,7 @@
 #'that can be used as a baseline.  Default is \code{NULL}, in which case no
 #'timepoint is used as a baseline value for gene expression.  Has to be
 #'\code{NULL} when comparing two treatment groups.
-#'@TODO See Details.
+#TODO See Details.
 #'
 #'@param group.var 
 #'in the case of several treatment groups, this is a factor of
@@ -63,7 +63,7 @@
 #'\code{Subject_ID} and the columns of \code{expr}.  It indicates to which
 #'treatment group each sample belongs to.  Default is \code{NULL}, which means
 #'that there is only one treatment group.  
-#'@TODO See Details.
+#TODO See Details.
 #'
 #'@param Group_ID_paired 
 #'a character vector of length \eqn{p} that is in the
@@ -71,7 +71,7 @@
 #'columns of \code{expr}.  This argument must not be \code{NULL} in the case of
 #'a paired analysis, and must be \code{NULL} otherwise.  Default is
 #'\code{NULL}.  
-#'@TODO See Details.
+#TODO See Details.
 #'
 #'@param ref 
 #'the group which is used as reference in the case of several
@@ -84,7 +84,7 @@
 #'computed in the case of several treatment groups.  Default is \code{NULL},
 #'which means that group of interest is the second group in alphabetical order
 #'of the labels of \code{group.var}.  
-#'@TODO See Details.
+#TODO See Details.
 #'
 #'@param FUNcluster 
 #'a function which accepts as first argument a matrix
@@ -169,8 +169,15 @@
 #'@param smooth 
 #'logical flag.  If \code{TRUE} and \code{showTrend} is also
 #'\code{TRUE}, the representation of each cluster \code{trend.fun} is smoothed
-#'using cubic polynoms (see \code{\link[ggplot2:stat_smooth]{stat_smooth}}.
-#'Default is \code{TRUE}.
+#'using cubic polynoms (see \code{\link[ggplot2:geom_smooth]{geom_smooth}}.
+#'Default is \code{TRUE}. 
+#'At the moment, must accept parameter \code{"na.rm"} (which is automatically set to \code{TRUE}). 
+#'This might change in future versions
+#'
+#'@param precluster 
+#'a vector of length \eqn{p} that is in
+#'the same order as \code{Subject_ID}, \code{TimePoint} and the columns of \code{expr} (when it is
+#'a dataframe), and that contains a prior clustering of the subjects. Default is \code{NULL}.
 #'
 #'@param time_unit 
 #'the time unit to be displayed (such as \code{"Y"},
@@ -205,6 +212,14 @@
 #'a numerical value giving the amount by which title text
 #'should be magnified relative to the default \code{1}.
 #'
+#'@param margins
+#'a numerical value giving the amount by which the margins
+#'should be reduced or increased relative to the default \code{1}.
+#'
+#'@param line.size
+#'a numerical value giving the amount by which the line sizes
+#'should be reduced or increased relative to the default \code{1}.
+#'
 #'@param y.lab.angle 
 #'a numerical value (in [0, 360]) giving the orientation by
 #'which y-label text should be turned (anti-clockwise).  Default is \code{90}.
@@ -238,13 +253,21 @@
 #'
 #'@author Boris P. Hejblum
 #'
-#'@seealso \code{\link{ggplot2}}, \code{\link[cluster:clusGap]{clusGap}}
+#'@seealso \code{\link[ggplot2:ggplot]{ggplot}}, \code{\link[cluster:clusGap]{clusGap}}
 #'
 #'@references Tibshirani, R., Walther, G. and Hastie, T., 2001, Estimating the
 #'number of data clusters via the Gap statistic, \emph{Journal of the Royal
 #'Statistical Society, Series B (Statistical Methodology)}, \bold{63}, 2:
 #'411--423.
 #'
+#'@import ggplot2
+#'
+#'@importFrom cluster agnes clusGap maxSE
+#'
+#'@importFrom stats cutree lm
+#'
+#'@export
+#'
 #'@examples
 #'
 #'data(data_simu_TcGSA)
@@ -278,6 +301,8 @@
 #'}
 #'
 #'\dontrun{
+#'library(grDevices)
+#'library(graphics)
 #'colval <- c(hsv(0.56, 0.9, 1),
 #'            hsv(0, 0.27, 1),
 #'            hsv(0.52, 1, 0.5),
@@ -310,7 +335,7 @@
 #'}
 #'
 plot1GS <- 
-	function(expr, gmt, Subject_ID,TimePoint, geneset.name, 
+	function(expr, gmt, Subject_ID, TimePoint, geneset.name, 
 			 baseline=NULL,
 			 group.var=NULL, Group_ID_paired=NULL, ref=NULL, group_of_interest=NULL,
 			 FUNcluster=NULL, clustering_metric="euclidian", clustering_method="ward", B=500,
@@ -318,17 +343,16 @@ plot1GS <-
 			 methodOptiClust = "firstSEmax",
 			 indiv="genes",
 			 verbose=TRUE,
-			 clustering=TRUE, showTrend=TRUE, smooth=TRUE,
+			 clustering=TRUE, showTrend=TRUE, smooth=TRUE, precluster=NULL, 
 			 time_unit="", title=NULL, y.lab=NULL, desc=TRUE,
-			 lab.cex=1, axis.cex=1, main.cex=1, y.lab.angle=90, x.axis.angle=45,
+			 lab.cex=1, axis.cex=1, main.cex=1, y.lab.angle=90, x.axis.angle=45, margins=1, line.size=1,
 			 y.lim=NULL, x.lim=NULL, 
 			 gg.add=list(theme()),
 			 plot=TRUE
 	){
 		
-		#   library(ggplot2)
-		#   library(cluster)
-		#   library(splines)
+		pre_clustering <- !is.null(precluster)
+		
 		capwords <- function(s, strict = FALSE){
 			cap <- function(s){
 				paste(toupper(substring(s,1,1)),{s <- substring(s,2); if(strict) tolower(s) else s},
@@ -337,19 +361,19 @@ plot1GS <-
 			sapply(strsplit(s, split = " "), cap, USE.NAMES = !is.null(names(s)))
 		}
 		
-		Fun_byIndex<-function(X, index, fun){
-			tapply(X, INDEX=index, FUN = fun)
+		Fun_byIndex<-function(X, index, fun, ...){
+			tapply(X, INDEX=index, FUN = fun, ...)
 		}
 		
 		if(is.null(FUNcluster)){
 			FUNcluster <- switch(EXPR=clustering_metric,
 								 sts= function(x, k, time, ...){
 								 	d <- STSdist(m=x, time = time)
-								 	clus <- cutree(agnes(d, ...), k=k)
+								 	clus <- stats::cutree(agnes(d, ...), k=k)
 								 	return(list("cluster"=clus))
 								 },
 								 function(x, k, ...){
-								 	clus <- cutree(agnes(x, method=clustering_method, metric=clustering_metric, ...), k=k)
+								 	clus <- stats::cutree(agnes(x, method=clustering_method, metric=clustering_metric, ...), k=k)
 								 	return(list("cluster"=clus))
 								 }
 			)
@@ -385,6 +409,7 @@ plot1GS <-
 			}
 		}
 		
+		
 		interest <- which(gmt$geneset.names==geneset.name)
 		if(length(interest)==0){
 			stop("The 'geneset.name' supplied is not in the 'gmt'")
@@ -402,17 +427,15 @@ plot1GS <-
 			Subject_ID <- rep(dimnames(expr_sel)[[2]], dim(expr_sel)[3])
 		}
 		
-		
-		
+		data_stand <- t(apply(X=data_sel, MARGIN=1, FUN=scale))
 		if(indiv=="genes"){
-			data_stand <- t(apply(X=data_sel, MARGIN=1, FUN=scale))
-			data_stand_MedianByTP <- t(apply(X=data_stand, MARGIN=1, FUN=Fun_byIndex, index=as.factor(TimePoint), fun=aggreg.fun))
+			data_stand_MedianByTP <- t(apply(X=data_stand, MARGIN=1, FUN=Fun_byIndex, index=as.factor(TimePoint), fun=aggreg.fun, na.rm=T))
 		}else if(indiv=="patients"){
-			data_stand <- t(apply(X=data_sel, MARGIN=1, FUN=scale))
 			data_tocast<-cbind.data.frame(TimePoint, Subject_ID, "M" = apply(X=data_stand, MARGIN=2, FUN=aggreg.fun))
 			data_stand_MedianByTP <- as.matrix(acast(data_tocast, formula="Subject_ID~TimePoint", value.var="M"))
 		}
 		
+		
 		if(!is.null(baseline)){
 			colbaseline <- which(sort(unique(TimePoint))==baseline)
 			if(length(colbaseline)==0){
@@ -421,86 +444,141 @@ plot1GS <-
 			data_stand_MedianByTP <- data_stand_MedianByTP-data_stand_MedianByTP[,colbaseline]
 		}
 		
-		if(clustering | showTrend){
-			if(verbose){
-				cat("Optimally clustering...\n")
-			}
-			kmax <- ifelse(dim(data_stand_MedianByTP)[1]>4, max_trends, dim(data_stand_MedianByTP)[1]-1)
-			if(kmax>=2){
-				if(clustering_metric!="sts"){
-					cG <- clusGap(x=data_stand_MedianByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE)
-					nc <- maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
-					clust <- FUNcluster(data_stand_MedianByTP, k=nc)$cluster
-				}else{
-					cG <- clusGap(x=data_stand_MedianByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE, time=as.numeric(colnames(data_stand_MedianByTP)))
-					nc <- maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
-					clust <- FUNcluster(data_stand_MedianByTP, k=nc, time=as.numeric(colnames(data_stand_MedianByTP)))$cluster
-				}    
-			}else{
-				nc <- 1
-				clust <- rep(1, dim(data_stand_MedianByTP)[1])
-			}
+		if(!pre_clustering && (clustering | showTrend) && length(which(is.na(data_stand_MedianByTP)))>0){
+			warning("Unable to compute optimal number of clusters/trends due to missing values\n")
+			clustering <- FALSE
+			showTrend <- FALSE
 			
-			medoids <- as.data.frame(t(apply(X=data_stand_MedianByTP, MARGIN=2, FUN=Fun_byIndex, index=clust, fun=trend.fun)))
-			if(dim(medoids)[1]==1){
-				medoids <- cbind.data.frame("TimePoint"= colnames(medoids), "1"=t(medoids))
+		}
+		
+		if(clustering | showTrend){
+			if(!pre_clustering){
+				if(verbose){
+					cat("Optimally clustering...\n")
+				}
+				kmax <- ifelse(dim(data_stand_MedianByTP)[1]>4, max_trends, dim(data_stand_MedianByTP)[1]-1)
+				
+				if(kmax>=2){
+					if(clustering_metric!="sts"){
+						cG <- clusGap(x=data_stand_MedianByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE)
+						nc <- maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
+						clust <- FUNcluster(data_stand_MedianByTP, k=nc)$cluster
+					}else{
+						cG <- clusGap(x=data_stand_MedianByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE, time=as.numeric(colnames(data_stand_MedianByTP)))
+						nc <- maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
+						clust <- FUNcluster(data_stand_MedianByTP, k=nc, time=as.numeric(colnames(data_stand_MedianByTP)))$cluster
+					}    
+				}else{
+					nc <- 1
+					clust <- rep(1, dim(data_stand_MedianByTP)[1])
+				}
+				
+				
+				
+				medoids <- as.data.frame(t(apply(X=data_stand_MedianByTP, MARGIN=2, FUN=Fun_byIndex, index=clust, fun=trend.fun)))
+				if(dim(medoids)[1]==1){
+					medoids <- cbind.data.frame("TimePoint"= colnames(medoids), "1"=t(medoids))
+				}else{
+					medoids <- cbind.data.frame("TimePoint"= rownames(medoids), medoids)
+				}
 			}else{
-				medoids <- cbind.data.frame("TimePoint"= rownames(medoids), medoids)
+				
+				clust <- precluster
+				medoids <- as.data.frame(t(apply(X=data_stand_MedianByTP, MARGIN=2, FUN=Fun_byIndex, 
+												 index=as.factor(as.numeric(precluster)), fun=trend.fun, na.rm=TRUE)))
+				if(nrow(medoids)==1){
+					medoids <- cbind.data.frame("TimePoint"= colnames(medoids), "1"=t(medoids))
+				}else{
+					medoids <- cbind.data.frame("TimePoint"= rownames(medoids), medoids)
+				}
+				colnames(medoids) <- c("TimePoint", levels(precluster))
 			}
 			if(verbose){
 				cat("DONE\n")
 			}
+			
+			
+			if(indiv=="patients"){
+				row_names <- (as.numeric(sub("P","",rownames(data_stand_MedianByTP))))
+				position<-NULL
+				for(i in 1:length(row_names)){
+					for(j in 1:length(row_names)){
+						if(row_names[i]==row_names[j]){
+							position<-c(position,j)
+						}
+					}
+				}
+				position<-order(as.character(position))
+			}
 		}else{
 			medoids <- cbind.data.frame("TimePoint"=colnames(data_stand_MedianByTP), "1"='NA')
 			clust <- rep(NA, dim(data_stand_MedianByTP)[1])
 		}
-		classif <- cbind.data.frame("ProbeID"=rownames(data_stand_MedianByTP), "Cluster"=clust)
-		classif <- classif[order(classif$Cluster), ]
-		meltedData <- melt(cbind.data.frame("Probe_ID"=rownames(data_stand_MedianByTP), "Cluster"=clust, data_stand_MedianByTP), id.vars=c("Probe_ID", "Cluster"), variable.name="TimePoint")
-		meltedStats <- melt(medoids, id.vars="TimePoint", variable.name="Cluster")
-		meltedData$Cluster <- as.factor(meltedData$Cluster)
 		
-		if(time_unit!=""){
-			meltedData$TimePoint <- paste(time_unit, meltedData$TimePoint, sep="")
-			meltedStats$TimePoint <- paste(time_unit, meltedStats$TimePoint, sep="")
-		}
-		else{
-			meltedData$TimePoint <- as.numeric(meltedData$TimePoint)
-			meltedStats$TimePoint <- as.numeric(meltedStats$TimePoint)
-		}
+		medoids$TimePoint <- as.numeric(as.character(medoids$TimePoint))
+		colnames(data_stand_MedianByTP) <- as.numeric(colnames(data_stand_MedianByTP))
+		
+		classif <- cbind.data.frame("ProbeID"=rownames(data_stand_MedianByTP), "Cluster"=clust)
+		
+		meltedData <- melt(cbind.data.frame("Probe_ID"=rownames(data_stand_MedianByTP), "Cluster"=classif$Cluster, data_stand_MedianByTP), id.vars=c("Probe_ID", "Cluster"), variable.name="TimePoint")
+		meltedStats <- melt(medoids, id.vars="TimePoint", variable.name="Cluster")
+		meltedData$Cluster <- as.character(meltedData$Cluster)
+		meltedData$TimePoint <- as.numeric(as.character(meltedData$TimePoint))
+		meltedStats$TimePoint <- as.numeric(as.character(meltedStats$TimePoint))
+		MeasPt <- unique(meltedData$TimePoint)
+		
+		
+		# 		browser()
+		# 		pca_data <- acast(meltedData, formula=TimePoint~Probe_ID)
+		# 		pca_res <- dudi.pca(pca_data)
+		# 		1
+		# 		pdf(width=5, height=4, file="~/PCAc1_M6_7.pdf")
+		# 		plot(y=-pca_res$l1[,1], x=rownames(pca_res$l1), type="l",
+		# 			 ylab="PCA 1st comp", xlab="Time (weeks)", main=g,
+		# 			 lwd=3, col="blue")
+		# 		dev.off()
+		
+		
 		
 		if(is.null(y.lim)){
-			y.max <- max(abs(meltedData$value))
+			y.max <- max(abs(meltedData$value), na.rm = TRUE)
 			y.min <- -y.max
 		}else{
 			y.max <- y.lim[2]
 			y.min <- y.lim[1]
 		}
 		if(is.null(x.lim)){
-			x.lim <- unique(meltedData$TimePoint)
-			if(time_unit==""){
-				x.lim <- c(min(x.lim), max(x.lim))
-			}
+			x.lim <- c(min(MeasPt), max(MeasPt))
 		}
 		
 		p <- (ggplot(meltedData, aes_string(x="TimePoint", y="value")) 
-			  + geom_hline(aes(y = 0), linetype=1, colour='grey50', size=0.4)
+			  + geom_hline(aes(yintercept = 0), linetype=1, colour='grey50', size=0.4*line.size)
+			  + theme(panel.border=element_rect(fill=NA, size=0.1*line.size, colour='grey50'),
+			  		axis.ticks=element_line(size=0.4*line.size, colour='grey50'))
 		)
 		
-		if(!clustering){
+		myalpha <- 1 
+		if(showTrend){
+			myalpha <- 0.5
+		}
+		
+		if(clustering | pre_clustering){
 			p <- (p
-				  + geom_line(aes_string(group="Probe_ID", colour="Probe_ID"), size=0.7)
-				  + scale_colour_manual(guide='none', name='probe ID', values=rainbow(length(select_probe)))
-			)
-		}else{
-			p <- (p
-				  + geom_line(aes_string(group="Probe_ID", colour="Cluster"), size=0.7)
+				  + geom_line(aes_string(group="Probe_ID", colour="Cluster"), size=0.5*line.size, alpha=myalpha)
 				  + guides(colour = guide_legend(override.aes=list(size=1, fill="white"), keywidth=2*lab.cex, 
 				  							   title.theme=element_text(size = 15*lab.cex, angle=0),
 				  							   label.theme=element_text(size = 9*lab.cex, angle=0)
 				  )
 				  )
 			)
+		}else{
+			p <- (p
+				  + geom_line(aes_string(group="Probe_ID", colour="Probe_ID"), size=0.5*line.size, alpha=myalpha)
+			)
+			if(indiv=="patients"){
+				p <- (p + guides(colour=guide_legend(title='Subject')))
+				#+ scale_colour_manual(guide='none', name='Subject', values=rainbow(length(select_probe))))
+			}
 		}
 		
 		p <- (p
@@ -510,37 +588,77 @@ plot1GS <-
 			  + theme(plot.title=element_text(size = 35*main.cex))
 			  + theme(panel.grid.minor = element_blank(), panel.grid.major = element_blank(), panel.background = element_rect(colour='grey40', fill = 'white'))
 			  + ylim(y.min, y.max)
-			  + xlim(x.lim)
-			  + theme(axis.title.y = element_text(size = 25*lab.cex, angle = y.lab.angle, vjust=0.3), axis.text.y = element_text(size=18*axis.cex, colour = 'grey40')) 
-			  + theme(axis.title.x = element_text(size = 25*lab.cex, angle = 0, vjust=-0.9), axis.text.x = element_text(size=18*axis.cex, colour = 'grey40', angle=x.axis.angle, vjust=0.5, hjust=0.5))
-			  + theme(plot.margin=unit(c(0.5, 0.5, 0.7, 1), 'lines'))
+			  + scale_x_continuous(breaks=MeasPt, 
+			  					 labels=paste(time_unit, MeasPt, sep="")
+			  )
+			  + theme(axis.title.y = element_text(size = 25*lab.cex, angle = y.lab.angle, vjust=0.8), axis.text.y = element_text(size=18*axis.cex, colour = 'grey40')) 
+			  + theme(axis.title.x = element_text(size = 25*lab.cex, angle = 0, vjust=0.5), axis.text.x = element_text(size=18*axis.cex, colour = 'grey40', angle=x.axis.angle, vjust=0.5, hjust=0.5))
+			  + theme(plot.margin=unit(margins*c(0.5, 0.7, 0.1, 0.5), 'lines'))
 			  + theme(legend.key=element_rect(fill="white"))
 		)
 		
+		
 		if(showTrend){
+			
 			if(!smooth){
-				p <- (p + geom_line(data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", linetype="Cluster"), size=4))
+				if(pre_clustering){
+					p <- (p + geom_line(data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", colour="Cluster"), size=3))
+				}else{
+					p <- (p + geom_line(data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", linetype="Cluster"), colour="black", size=3))
+				}
 			}else{
-				if(length(unique(meltedStats$TimePoint))<4){
+				if(length(MeasPt)<4){
 					stop("Not enough time points to estimate a smoothed trend! 
     				 Set 'smooth' argument to 'FALSE'.\n")
 				}
-				p <- (p + stat_smooth(formula=y~poly(x,3), data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", linetype="Cluster"), size=4, se=FALSE, method="lm", color="black"))
+				# spline_knots <- ifelse(length(MeasPt)>6, 
+				# 						floor((length(MeasPt)-2)/2), 
+				# 						1
+				# )
+				if(pre_clustering){
+					p <- (p 
+						  + geom_smooth(formula=y~poly(x, 3), data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", colour="Cluster", size="1.5"), se=FALSE, method="lm")
+						  # + geom_smooth(data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", colour="Cluster"), size=1.7*line.size, se=FALSE, method="loess")
+						  + guides(size="none")
+					)
+				}else{
+					p <- p + geom_smooth(formula=y~poly(x, 3), data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", linetype="Cluster"), size=1.7*line.size, colour="black", se=FALSE, method="lm")
+						  # + geom_smooth(data=meltedStats, aes_string(x="TimePoint", y="value", group="Cluster", linetype="Cluster"), size=1.7*line.size, colour="black", se=FALSE, method="loess")
+					if(!clustering){
+						p <- p + scale_linetype_manual(name=paste("Cluster", capwords(trend.fun)), values=as.numeric(levels(meltedStats$Cluster))+1)
+						
+					}
+					#y~ns(x, knots=spline_knots)
+				}
+				if(length(unique(meltedStats$Cluster))==1 | length(unique(meltedStats$Group))==1){
+					p <- (p + guides(linetype="none"))
+				}
+				
+				if(clustering){
+					p <- (p + guides(size="none")
+						  + scale_linetype_manual(name=paste("Cluster", capwords(trend.fun)), values=as.numeric(levels(meltedStats$Cluster))+1,#as.numeric(levels(meltedStats$Cluster))+1, 
+						  						guide=guide_legend(override.aes=list(size=1), keywidth=2*lab.cex, 
+						  										   title.theme=element_text(size = 17*lab.cex, angle=0),
+						  										   label.theme=element_text(size = 12*lab.cex, angle=0)
+						  						)
+						  )
+					)
+				}else{
+					p <- p + scale_size_continuous(name="", labels=capwords(trend.fun))
+				}	
 			}
-			p <- p + scale_linetype_manual(name=paste("Cluster", capwords(trend.fun)), values=as.numeric(levels(meltedStats$Cluster))+1, 
-										   guide=guide_legend(override.aes=list(size=1), keywidth=2*lab.cex, 
-										   				   title.theme=element_text(size = 17*lab.cex, angle=0),
-										   				   label.theme=element_text(size = 12*lab.cex, angle=0)
-										   )
-			)
 		}
+		
 		for(a in gg.add){
 			p <- p + a
 		}
 		if(plot){
 			print(p)
 		}
+		
+		classif <- classif[order(classif$Cluster), ]
 		invisible(classif)
+		
 	}
 
 
